# Description

This is an example to show how to update the firmware through HCI script. The detailed instruction for how to run the example is in msdk FW_update_hci folder. 

hello_world.bin is a program which will print the following result: 
```
Second Application: Hello World!
```
